@@ -3,7 +3,7 @@ from sklearn.feature_extraction import DictVectorizer
 from sklearn.feature_extraction.text import CountVectorizer, TfidfVectorizer
 import joblib
 from tensorflow.keras.utils import to_categorical
-from lib import Lib
+from .lib import Lib
 from sklearn.preprocessing import MinMaxScaler
 import nltk
 
